@@ -22,6 +22,7 @@
 //üäöß 
 FourXle::FourXle(Molecule *mole_, ChGL *chgl_,QToolBar *toolView, QProgressBar *bar, double resol, double wght){
   //  printf("FourXle\n");
+  ownfcf6_=NULL;
   mole =mole_;
   f000=0.0;
   overridef000=-1.0;
@@ -35,11 +36,11 @@ FourXle::FourXle(Molecule *mole_, ChGL *chgl_,QToolBar *toolView, QProgressBar *
   maptrunc = 2;
   mapcontrol=NULL;
   resDir=QDir::current();
- // for (int i=0; i<37; i++) chgl->foubas[i]=0;
+  // for (int i=0; i<37; i++) chgl->foubas[i]=0;
   /*
-    QVector< QVector< float > > chgl->fchgl->fVertexes;
-    QVector< QVector< float > > chgl->fNormals;
-  */
+     QVector< QVector< float > > chgl->fchgl->fVertexes;
+     QVector< QVector< float > > chgl->fNormals;
+     */
   chgl->fVertexes.resize(28);
   chgl->fNormals.resize(28);
   HKLMX=200;
@@ -313,8 +314,12 @@ FourXle::FourXle(Molecule *mole_, ChGL *chgl_,QToolBar *toolView, QProgressBar *
 
     md->setLayout(mdmain);
     md->setModal (false);
-  ownfcf6=new QCheckBox("fcf6 by hkl");
-  ownfcf6->setChecked(MYFCF);
+    ownfcf6=new QCheckBox("fcf6 by hkl");
+    ownfcf6->setChecked(MYFCF);
+    ownfcf6_=new QCheckBox("Compute fcf6 file from structure factors and observed data from hkl file");
+    ownfcf6_->setChecked(MYFCF);
+    amdl->addWidget(ownfcf6_);
+    connect(ownfcf6_,SIGNAL(toggled(bool)),this , SLOT(doMapsNow(bool)));
     connect(doMaps,SIGNAL(toggled(bool)),this , SLOT(doMapsNow(bool)));
     mole->einstellung->beginGroup("Window");//mole->einstellung->beginGroup("");
     if (mole->einstellung->contains("Fo-Map")) chgl->foact->setChecked(mole->einstellung->value("Fo-Map").toBool());
@@ -330,23 +335,27 @@ FourXle::FourXle(Molecule *mole_, ChGL *chgl_,QToolBar *toolView, QProgressBar *
     if (mole->einstellung->contains("Calculate-Maps")) doMaps->setChecked(mole->einstellung->value("Calculate-Maps").toBool());
     if (mole->einstellung->contains("KeepMapIsoValues")){
       keepIso->setChecked(mole->einstellung->value("KeepMapIsoValues").toBool());
-     // keepiso->setChecked(mole->einstellung->value("KeepMapIsoValues").toBool());
+      // keepiso->setChecked(mole->einstellung->value("KeepMapIsoValues").toBool());
     }
     mole->einstellung->endGroup();    
     schnittart(maptrunc);
-//    printf("@!#$  %p\n",mole->einstellung);
+    //    printf("@!#$  %p\n",mole->einstellung);
     md->hide();
   }
   connect(ownfcf6,SIGNAL(toggled(bool)),this , SLOT(doMapsNow(bool)));
+  isBelo=false;
+  printf("constr. belo?%d\n",isBelo);
   //printf("%s\n",ENUS);
 }
 
 FourXle::~FourXle(){
-    if (chgl!=NULL) disconnect(chgl,SIGNAL(diffscroll(int ,int )),0,0);
-    if (chgl!=NULL) disconnect(chgl,SIGNAL(neuemitte(V3)),0,0);
-    if (chgl!=NULL) disconnect(chgl,SIGNAL(inimibas()),0,0);
+    printf("Maps will close...\n");
+  if (chgl!=NULL) disconnect(chgl,SIGNAL(diffscroll(int ,int )),0,0);
+  if (chgl!=NULL) disconnect(chgl,SIGNAL(neuemitte(V3)),0,0);
+  if (chgl!=NULL) disconnect(chgl,SIGNAL(inimibas()),0,0);
   killmaps();
   delete doMaps; 
+  printf("Maps closed.\n");
 }
 
 void FourXle::mapDefault(){
@@ -397,9 +406,9 @@ void FourXle::keepIsoValues(bool b){
 }
 
 void FourXle::updateLines(){
-    chgl->lintrans=lineTrans->value();
-    chgl->linwidth=lineWidth->value();
-    chgl->updateGL();
+  chgl->lintrans=lineTrans->value();
+  chgl->linwidth=lineWidth->value();
+  chgl->updateGL();
 }
 
 void FourXle::killFourXleFirst(){
@@ -410,10 +419,19 @@ void FourXle::killFourXleFirst(){
 }
 
 void FourXle::doMapsNow(bool b){
+  //isBelo=false;
   bool bb=MYFCF;
-  MYFCF=ownfcf6->isChecked();
+  bool B = (MYFCF!=ownfcf6->isChecked())||(MYFCF!=ownfcf6_->isChecked());
+  MYFCF=(B)?!MYFCF:MYFCF;
   if (bb!=MYFCF) {
-    emit reloadRes();return;
+    ownfcf6->disconnect();
+    ownfcf6_->disconnect();
+    ownfcf6->setChecked(MYFCF);
+    ownfcf6_->setChecked(MYFCF);
+    connect(ownfcf6,SIGNAL(toggled(bool)),this , SLOT(doMapsNow(bool)));
+    connect(ownfcf6_,SIGNAL(toggled(bool)),this , SLOT(doMapsNow(bool)));
+    emit reloadRes();
+    return;
   } 
   if (!b) {
     killmaps(); 
@@ -429,17 +447,18 @@ void FourXle::doMapsNow(bool b){
     } else {        
       if (mapcontrol!=NULL) mapcontrol->setVisible(true);
       if (!hamrsho) {
-          sigma[0] = sigmaFoFc();
-          sigma[1]  = sigmaFo();
-          iso[1]= sigma[0] * 2.7f;
-          iso[0]= sigma[1] * 1.2f;
-          fomaps->setValue(iso[0]);
-          difmaps->setValue(fabs(iso[1]));
-          inimap();
+        sigma[0] = sigmaFoFc();
+        sigma[1]  = sigmaFo();
+        iso[1]= sigma[0] * 2.7f;
+        iso[0]= sigma[1] * 1.2f;
+        fomaps->setValue(iso[0]);
+        difmaps->setValue(fabs(iso[1]));
+        inimap();
       }
     }
     chgl->updateGL();
   }
+
 } 
 
 void FourXle::controlMap(){
@@ -461,9 +480,11 @@ void FourXle::controlMap(){
 }
 
 void FourXle::killmaps(){
+  printf("KM belo?%d %p %p %p\n",isBelo,chgl,datfo_fc,datfo);
+  isBelo=false;
   /*! deletes all fourier maps and frees the memory
   */
- // printf("I kill maps\n");
+  // printf("I kill maps\n");
 
   if (chgl!=NULL) disconnect(chgl,SIGNAL(diffscroll(int ,int )),0,0);
   if (chgl!=NULL) disconnect(chgl,SIGNAL(neuemitte(V3)),0,0);
@@ -479,7 +500,7 @@ void FourXle::killmaps(){
   if (noGoMap!=NULL) free(noGoMap);
   nodex=nodey=nodez=NULL;noGoMap=NULL;
   datfo=datfo_fc=NULL;
- // printf("I kill maps %d!!\n",chgl->fVertexes.size());
+   printf("I kill maps %d! %d!\n",chgl->fVertexes.size(),chgl->fNormals.size());
   for (int i=0; i<chgl->fVertexes.size(); i++) chgl->fVertexes[i].clear();
   for (int i=0; i<chgl->fNormals.size(); i++) chgl->fNormals[i].clear();
 
@@ -919,9 +940,25 @@ bool FourXle::loadFouAndPerform(const char filename[],bool neu){
       n4=n2*n1;
       n5=n3*n4;
       datfo=(float*) malloc(sizeof(float)*n5);
-      if (datfo==NULL)return false;
+      if (datfo==NULL){
+          fprintf(stderr,"Too less memory for F_observed!\n");
+          datfo=NULL;
+          mapDefault();
+          info="";
+          emit bigmessage(QString("<font color=red>Could not allocate sufficient memory for density maps. Defaults have been applied.</font> (Try to tick and un tick fcf6 by hkl)"));
+          return false;
+      }
       datfo_fc=(float*) malloc(sizeof(float)*n5);
-      if (datfo_fc==NULL)return false;
+      if (datfo_fc==NULL){
+          fprintf(stderr,"Too less memory for F_observed - F_calculated!\n");
+          free(datfo);
+          datfo=NULL;
+          datfo_fc=NULL;          
+          mapDefault();
+          info="";
+          emit bigmessage(QString("<font color=red>Could not allocate sufficient memory for density maps. Defaults have been applied.</font> (Try to tick and un tick fcf6 by hkl)"));
+          return false;
+      }
       DX=1.0f/n1;
       DY=1.0f/n2;
       DZ=1.0f/n3;
@@ -939,7 +976,17 @@ bool FourXle::loadFouAndPerform(const char filename[],bool neu){
       for (int i=0; i<n5; i++){B[i][0]=0;B[i][1]=0;}
 #else
       B=(kiss_fft_cpx*)KISS_FFT_MALLOC(nbytes = (sizeof(kiss_fft_cpx)*n5));
-      if (B==NULL)return false; 
+      if (B==NULL){
+          fprintf(stderr,"Too less memory for FFT map!\n");
+          free(datfo);
+          free(datfo_fc);
+          datfo=NULL;
+          datfo_fc=NULL;
+          mapDefault();
+          info="";
+          emit bigmessage(QString("<font color=red>Could not allocate sufficient memory for density maps. Defaults have been applied.</font> (Try to tick and un tick fcf6 by hkl)"));
+          return false;
+      }
       for (int i=0; i<n5; i++){B[i].r=0;B[i].i=0;}
 #endif
       for (int i=0; i<nr;i++){
@@ -1032,18 +1079,6 @@ bool FourXle::loadFouAndPerform(const char filename[],bool neu){
 #endif
       }
       sigma[typ]=t=sqrt((DS/n5)-((DM/n5)*(DM/n5)));
-
-      /*      if (typ==1){
-              double r=9999.0/(maZ-miZ);
-              double s=1/r;
-              FILE *map=fopen("test.map","wb");
-              fprintf(map,"%5d%5d%5d%5d%12.8f%12.6f%12.6f\n",1,n1,n2,n3,s,miZ,t);
-              for (int mzi=0; mzi<n5; mzi++){
-              fprintf(map,"%4d ",(int)( (B[mzi].r-miZ)*r));
-              if (mzi%16==15)fprintf(map,"\n");
-              }
-              fclose(map);
-              }*/
       free(B);
     }//1
   }//2
@@ -1055,13 +1090,66 @@ bool FourXle::loadFouAndPerform(const char filename[],bool neu){
   mole->frac2kart(urs,urs);
 
   nodex= (FNode*)malloc(sizeof(FNode)*n5);
-  if (nodex==NULL)return false; 
+  if (nodex==NULL){
+      fprintf(stderr,"Too less memory for node X!\n");
+      free(datfo);
+      free(datfo_fc);
+      datfo=NULL;
+      datfo_fc=NULL;
+      mapDefault();
+      info="";
+      emit bigmessage(QString("<font color=red>Could not allocate sufficient memory for density maps. Defaults have been applied.</font> (Try to tick and un tick fcf6 by hkl)"));
+      return false;
+  }
   nodey= (FNode*)malloc(sizeof(FNode)*n5);
-  if (nodey==NULL)return false; 
+  if (nodey==NULL){
+      fprintf(stderr,"Too less memory for node Y!\n");
+      free(nodex);
+      free(datfo);
+      free(datfo_fc);
+      nodex = NULL;
+      datfo = NULL;
+      datfo_fc = NULL;
+      mapDefault();
+      info="";
+      emit bigmessage(QString("<font color=red>Could not allocate sufficient memory for density maps. Defaults have been applied.</font> (Try to tick and un tick fcf6 by hkl)"));
+      return false;
+  }
   nodez= (FNode*)malloc(sizeof(FNode)*n5);
-  if (nodez==NULL)return false; 
+  if (nodez==NULL){
+      fprintf(stderr,"Too less memory for node Z!\n");
+      free(nodex);
+      free(nodey);
+      free(datfo);
+      free(datfo_fc);
+      nodex = NULL;
+      nodey = NULL;
+      datfo = NULL;
+      datfo_fc = NULL;
+      mapDefault();
+      info="";
+      emit bigmessage(QString("<font color=red>Could not allocate sufficient memory for density maps. Defaults have been applied.</font> (Try to tick and un tick fcf6 by hkl)"));
+      return false;
+  }
   noGoMap= (int*) malloc(sizeof(int)*n5*27);
-  if (noGoMap==NULL)return false; 
+  if (noGoMap==NULL){
+      fprintf(stderr,"Too less memory for noGoMap!\n");
+
+      free(nodex);
+      free(nodey);
+      free(nodez);
+      free(datfo);
+      free(datfo_fc);
+      nodex= NULL;
+      nodey= NULL;
+      nodez= NULL;
+      datfo= NULL;
+      datfo_fc= NULL;
+      mapDefault();
+      info="";
+      emit bigmessage(QString("<font color=red>Could not allocate sufficient memory for density maps. Defaults have been applied.</font> (Try to tick and un tick fcf6 by hkl)"));
+      return false;
+  }
   for (int no=0;no<(n5*27);no++) noGoMap[no]=0; 
   for (int o=0; o<n5;o++){
     nodex[o].flag=0;
@@ -1112,95 +1200,129 @@ bool FourXle::loadFouAndPerform(const char filename[],bool neu){
 }
 
 bool FourXle::loadMap(int NX, int NY, int NZ, float *dat){
-    killmaps();
-    /*
-	if (datfo!=NULL) free(datfo);
-	if (datfo_fc!=NULL) free(datfo_fc);
-	if (nodex!=NULL) free(nodex);
-	if (nodey!=NULL) free(nodey);
-	if (nodez!=NULL) free(nodez);
-	if (noGoMap!=NULL) free(noGoMap);
-	nodex = nodey = nodez = NULL;
-	noGoMap = NULL;
-	datfo = datfo_fc=NULL;
+  bool wbi=isBelo;
+  killmaps();
+  isBelo=wbi;
 
-    chgl->fVertexes.clear();
-    chgl->fNormals.clear();
-    */
-    n1=NX;
-    n2=NY;
-    n3=NZ;
-    n4=n2*n1;
-    n5=n3*n4;
-    datfo=(float*) malloc(sizeof(float)*n5);
-	if (datfo==NULL){free(datfo_fc);return false;}
-    for (int i=0; i<n5; i++)datfo[i]=0.0f;
-    datfo_fc=dat;
+  n1=NX;
+  n2=NY;
+  n3=NZ;
+  n4=n2*n1;
+  n5=n3*n4;
+  datfo=(float*) malloc(sizeof(float)*n5);
+  if (datfo==NULL){
+      fprintf(stderr,"Too less memory for F_observed - F_calculated!\n");
+      free(datfo_fc);
+      mapDefault();
+      info="";
+      emit bigmessage(QString("<font color=red>Could not allocate sufficient memory for density maps. Defaults have been applied.</font> (Try to tick and un tick fcf6 by hkl)"));
+      return false;
+  }
+  for (int i=0; i<n5; i++)datfo[i]=0.0f;
+  datfo_fc=dat;
 
-    sigma[0] = sigmaFoFc();
-    sigma[1] = sigmaFo();
-    iso[1]= sigma[0] * 2.5f;
-    iso[0]= sigma[1] * 1.2f;
-    fomaps->setValue(iso[0]);
-    difmaps->setValue(iso[1]);
-	
-    urs=V3(0,0,0);int gt=0;
-    for (int i=0; i<mole->showatoms.size();i++)
-      if (mole->showatoms.at(i).an>-1) {urs+=mole->showatoms.at(i).frac;gt++;}
-    urs*=1.0/gt;
-    urs=V3(1,1,1)-1.0*urs;
-    mole->frac2kart(urs,urs);
-    nodex= (FNode*)malloc(sizeof(FNode)*n5);
-    if (nodex==NULL){free(datfo); free(datfo_fc); return false;}
-    nodey= (FNode*)malloc(sizeof(FNode)*n5);
-    if (nodey==NULL){free(datfo); free(datfo_fc);free(nodex); return false;}
-    nodez= (FNode*)malloc(sizeof(FNode)*n5);
-    if (nodez==NULL){free(datfo); free(datfo_fc);free(nodex); free(nodey); return false;}
-    noGoMap= (int*) malloc(sizeof(int)*n5*27);
-    if (noGoMap==NULL){free(datfo); free(datfo_fc);free(nodex); free(nodey); free(nodez); return false;}
-    for (int no=0;no<(n5*27);no++) noGoMap[no]=0;
-    for (int o=0; o<n5;o++){
-      nodex[o].flag=0;
-      nodey[o].flag=0;
-      nodez[o].flag=0;
-    }
-    dx = V3(1.0 / (n1), 0, 0);
-    dy = V3(0, 1.0 / (n2), 0);
-    dz = V3(0, 0, 1.0 / (n3));
-    mole->frac2kart(dx,dx);
-    mole->frac2kart(dy,dy);
-    mole->frac2kart(dz,dz);
-    delDA[ 0]=  -n1*dx -n2*dy -n3*dz;//nx ny,nz??
-    delDA[ 1]=         -n2*dy -n3*dz;
-    delDA[ 2]=   n1*dx -n2*dy -n3*dz;
-    delDA[ 3]=  -n1*dx        -n3*dz;
-    delDA[ 4]=                -n3*dz;
-    delDA[ 5]=   n1*dx        -n3*dz;
-    delDA[ 6]=  -n1*dx +n2*dy -n3*dz;
-    delDA[ 7]=          n2*dy -n3*dz;
-    delDA[ 8]=   n1*dx +n2*dy -n3*dz;
-    delDA[ 9]=  -n1*dx -n2*dy       ;
-    delDA[10]=         -n2*dy       ;
-    delDA[11]=   n1*dx -n2*dy       ;
-    delDA[12]=  -n1*dx              ;
-    delDA[13]=  V3(0,0,0)           ;
-    delDA[14]=   n1*dx              ;
-    delDA[15]=  -n1*dx +n2*dy       ;
-    delDA[16]=          n2*dy       ;
-    delDA[17]=   n1*dx +n2*dy       ;
-    delDA[18]=  -n1*dx -n2*dy +n3*dz;
-    delDA[19]=         -n2*dy +n3*dz;
-    delDA[20]=   n1*dx -n2*dy +n3*dz;
-    delDA[21]=  -n1*dx        +n3*dz;
-    delDA[22]=                +n3*dz;
-    delDA[23]=   n1*dx        +n3*dz;
-    delDA[24]=  -n1*dx +n2*dy +n3*dz;
-    delDA[25]=          n2*dy +n3*dz;
-    delDA[26]=   n1*dx +n2*dy +n3*dz;
-    rr =  mapprec->value();
-    rw = weak->value();
-    //gen_surface_silent();
-    return true;
+  sigma[0] = sigmaFoFc();
+  sigma[1] = sigmaFo();
+  iso[1]= sigma[0] * 2.5f;
+  iso[0]= sigma[1] * 1.2f;
+  fomaps->setValue(iso[0]);
+  difmaps->setValue(iso[1]);
+
+  urs=V3(0,0,0);int gt=0;
+  for (int i=0; i<mole->showatoms.size();i++)
+    if (mole->showatoms.at(i).an>-1) {urs+=mole->showatoms.at(i).frac;gt++;}
+  urs*=1.0/gt;
+  urs=V3(1,1,1)-1.0*urs;
+  mole->frac2kart(urs,urs);
+  nodex= (FNode*)malloc(sizeof(FNode)*n5);
+  if (nodex==NULL){
+      fprintf(stderr,"Too less memory for node X!\n");
+      free(datfo);
+      free(datfo_fc);
+      mapDefault();
+      info="";
+      emit bigmessage(QString("<font color=red>Could not allocate sufficient memory for density maps. Defaults have been applied.</font> (Try to tick and un tick fcf6 by hkl)"));
+      return false;
+  }
+  nodey= (FNode*)malloc(sizeof(FNode)*n5);
+  if (nodey==NULL){
+      fprintf(stderr,"Too less memory for node Y!\n");
+      free(datfo);
+      free(datfo_fc);
+      free(nodex);
+      mapDefault();
+      info="";
+      emit bigmessage(QString("<font color=red>Could not allocate sufficient memory for density maps. Defaults have been applied.</font> (Try to tick and un tick fcf6 by hkl)"));
+      return false;
+  }
+  nodez= (FNode*)malloc(sizeof(FNode)*n5);
+  if (nodez==NULL){
+      fprintf(stderr,"Too less memory for node Z!\n");
+      free(datfo);
+      free(datfo_fc);
+      free(nodex);
+      free(nodey);
+      mapDefault();
+      info="";
+      emit bigmessage(QString("<font color=red>Could not allocate sufficient memory for density maps. Defaults have been applied.</font> (Try to tick and un tick fcf6 by hkl)"));
+      return false;
+  }
+  noGoMap= (int*) malloc(sizeof(int)*n5*27);
+  if (noGoMap==NULL){
+      fprintf(stderr,"Too less memory for noGoMap!\n");
+      free(datfo);
+      free(datfo_fc);
+      free(nodex);
+      free(nodey);
+      free(nodez);
+      mapDefault();
+      info="";
+      emit bigmessage(QString("<font color=red>Could not allocate sufficient memory for density maps. Defaults have been applied.</font> (Try to tick and un tick fcf6 by hkl)"));
+      return false;
+  }
+  for (int no=0;no<(n5*27);no++) noGoMap[no]=0;
+  for (int o=0; o<n5;o++){
+    nodex[o].flag=0;
+    nodey[o].flag=0;
+    nodez[o].flag=0;
+  }
+  dx = V3(1.0 / (n1), 0, 0);
+  dy = V3(0, 1.0 / (n2), 0);
+  dz = V3(0, 0, 1.0 / (n3));
+  mole->frac2kart(dx,dx);
+  mole->frac2kart(dy,dy);
+  mole->frac2kart(dz,dz);
+  delDA[ 0]=  -n1*dx -n2*dy -n3*dz;//nx ny,nz??
+  delDA[ 1]=         -n2*dy -n3*dz;
+  delDA[ 2]=   n1*dx -n2*dy -n3*dz;
+  delDA[ 3]=  -n1*dx        -n3*dz;
+  delDA[ 4]=                -n3*dz;
+  delDA[ 5]=   n1*dx        -n3*dz;
+  delDA[ 6]=  -n1*dx +n2*dy -n3*dz;
+  delDA[ 7]=          n2*dy -n3*dz;
+  delDA[ 8]=   n1*dx +n2*dy -n3*dz;
+  delDA[ 9]=  -n1*dx -n2*dy       ;
+  delDA[10]=         -n2*dy       ;
+  delDA[11]=   n1*dx -n2*dy       ;
+  delDA[12]=  -n1*dx              ;
+  delDA[13]=  V3(0,0,0)           ;
+  delDA[14]=   n1*dx              ;
+  delDA[15]=  -n1*dx +n2*dy       ;
+  delDA[16]=          n2*dy       ;
+  delDA[17]=   n1*dx +n2*dy       ;
+  delDA[18]=  -n1*dx -n2*dy +n3*dz;
+  delDA[19]=         -n2*dy +n3*dz;
+  delDA[20]=   n1*dx -n2*dy +n3*dz;
+  delDA[21]=  -n1*dx        +n3*dz;
+  delDA[22]=                +n3*dz;
+  delDA[23]=   n1*dx        +n3*dz;
+  delDA[24]=  -n1*dx +n2*dy +n3*dz;
+  delDA[25]=          n2*dy +n3*dz;
+  delDA[26]=   n1*dx +n2*dy +n3*dz;
+  rr =  mapprec->value();
+  rw = weak->value();
+  //gen_surface_silent();
+  return true;
 
 }
 
@@ -1320,41 +1442,9 @@ void FourXle::exportMaps(int na, const char filename[], const char atomlist[]){
         i++;
       }
   fclose(fof1);
-  //
-  //F1-F2 MAP
-  //
-
-  /*
-     if (datf1_f2!=NULL){
-     strncpy(f1f2name,filename,len-4);
-     f1f2name[len-4]='\0';
-     strcat(f1f2name,"_fmod1-fmod2_densitymap.cube");
-     f1f2=fopen(f1f2name,"w");
-     if (f1f2==NULL) return ;
-     fprintf(f1f2,"F fmod1-fmod2 map written by MoleCoolQt\nDifferene density fmod1-fmod2 in xd.fou transformed using fft\n");
-     fprintf(f1f2,"%5d%12.6f%12.6f%12.6f\n",na,
-     (dx1.x+dy1.x+dz1.x)*0.5/a0,
-     (dx1.y+dy1.y+dz1.y)*0.5/a0,
-     (dx1.z+dy1.z+dz1.z)*0.5/a0
-  //0.0,0.0,(dx.z+dy.z+dz.z)/a0
-  );
-  fprintf(f1f2,"%5d%12.6f%12.6f%12.6f\n",n1,dx1.x/a0,dx1.y/a0,dx1.z/a0);
-  fprintf(f1f2,"%5d%12.6f%12.6f%12.6f\n",n2,dy1.x/a0,dy1.y/a0,dy1.z/a0);
-  fprintf(f1f2,"%5d%12.6f%12.6f%12.6f"  ,n3,dz1.x/a0,dz1.y/a0,dz1.z/a0);//no newline here because it is in atomlist
-  fprintf(f1f2,"%s",atomlist);
-  for (int xi=0;xi<n1;xi++)
-  for (int yi=0;yi<n2;yi++)
-  for (int zi=0;zi<n3;zi++)
-  {
-  //   fprintf(f1f2,"%s%13.5E",(((i%6)==0)?"\n":""),datf1_f2[dex(xi,yi,zi)]*factor);
-  fprintf(f1f2,"%s",QString("%1%2").arg(((i%6)==0)?"\n":"").arg(datf1_f2[dex(xi,yi,zi)]*factor,13,'E',5).toStdString().c_str());
-  i++;
-  }
-
-  fclose(f1f2);
   }
   // */
-}
+//}
 
 int FourXle::readHeader(const char *filename){
   /*! reads the header of an fcf file
@@ -1575,7 +1665,7 @@ void FourXle::sorthkl(int nr, Rec r[]){
 }
 
 void FourXle::bewegt(V3 nm){/*!moves the rotation center to nm*/
-    printf("moved\n");
+  printf("moved\n");
   V3 v , alturs=urs;
   mole->kart2frac(nm,v);
   urs=V3(1,1,1)-1.0*v;
@@ -1600,18 +1690,19 @@ void FourXle::inimap(){/*! reinitializes the display lists for screenshots*/
   balken->show();
   balkenstep=0;
   gen_surface(false);
+  printf("for screenies\n");
 
 }
 
 void FourXle::gen_surface(bool neu,int imin,int imax){
-    balken->show();
-    GenMapWorker *w = new GenMapWorker(chgl, mole, this, neu, imin, imax);
-    connect(w, SIGNAL(finished()),this, SLOT(reportInfo()));
-    connect(w, SIGNAL(finished()), chgl, SLOT(updateGL()));
-    connect(w, SIGNAL(progress(int)), balken, SLOT(setValue(int)));
-    connect(w, SIGNAL(finished()), balken,SLOT(hide()));
-    connect(w, SIGNAL(finished()), w, SLOT(deleteLater()));
-    w->start();
+  balken->show();
+  GenMapWorker *w = new GenMapWorker(chgl, mole, this, neu, imin, imax);
+  connect(w, SIGNAL(finished()),this, SLOT(reportInfo()));
+  connect(w, SIGNAL(finished()), chgl, SLOT(updateGL()));
+  connect(w, SIGNAL(progress(int)), balken, SLOT(setValue(int)));
+  connect(w, SIGNAL(finished()), balken,SLOT(hide()));
+  connect(w, SIGNAL(finished()), w, SLOT(deleteLater()));
+  w->start();
 }
 //GenMapWorker
 
@@ -1700,13 +1791,13 @@ void GenMapWorker::gen_surface(bool neu,int imin,int imax){
         break;
       case 2:                   
         if (neu) fxle->iso[0]=(fxle->keepIso->isChecked())?FXO*1.2f:fxle->sigma[1]*1.2f;
-     //   printf("blau %g %d\n",fxle->iso[0],neu);
+        //   printf("blau %g %d\n",fxle->iso[0],neu);
         fxle->mtyp=0;
         break;
       case 3:                   
         if (neu) fxle->iso[0]=(fxle->keepIso->isChecked())?-FXO*1.2f:-fxle->sigma[1]*1.2f;
         else fxle->iso[0]=-fabs(fxle->iso[0]);
-     //   printf("orange %g %d\n",fxle->iso[0],neu);
+        //   printf("orange %g %d\n",fxle->iso[0],neu);
         fxle->mtyp=0;
         break;
     }
@@ -1723,33 +1814,12 @@ void GenMapWorker::gen_surface(bool neu,int imin,int imax){
       }
     }
     emit progress(fxle->balkenstep+=fxle->n3);
-    /*if (chgl->lighting->isChecked())    {
 
-      {
-        int ix,iy,iz;
-        for(iz=0; iz<=fxle->n3; iz++ ){
-          for(iy=0; iy<=fxle->n2; iy++ ){
-            for(ix=0; ix<=fxle->n1; ix++ ){
-              int kk=fxle->dex(ix,iy,iz);
-              if( fxle->nodex[kk] ){
-                fxle->nodex[kk].normal = fxle->CalcNormalX(ix,iy,iz);
-              }
-              if( fxle->nodey[kk] ){
-                fxle->nodey[kk].normal = fxle->CalcNormalY(ix,iy,iz);
-              }
-              if( fxle->nodez[kk] ){
-                fxle->nodez[kk].normal = fxle->CalcNormalZ(ix,iy,iz);
-              }
-            }
-          }
-        }
-      }
-    }// */
     int mper=(chgl->niceTrans->isChecked())?6:1;
     for (int pers=0;pers<mper;pers++){        
-        int facnpers=fac+pers*4;
-        chgl->fVertexes[facnpers].clear();
-        chgl->fNormals[facnpers].clear();
+      int facnpers=fac+pers*4;
+      chgl->fVertexes[facnpers].clear();
+      chgl->fNormals[facnpers].clear();
 
       int h,k,l;
       int step=0;
@@ -1848,20 +1918,20 @@ void GenMapWorker::gen_surface(bool neu,int imin,int imax){
   fxle->connect(chgl,SIGNAL(diffscroll(int ,int )),fxle,SLOT(change_iso(int ,int )));
   chgl->fofcact->setVisible(!chgl->fVertexes[0].isEmpty());
   chgl->foact->setVisible(!chgl->fVertexes[2].isEmpty());
-//  printf("Fomap ist da? %d Fo-Fcmap ist da? %d \n",chgl->fVertexes[2].isEmpty(),chgl->fVertexes[0].isEmpty());
+  //  printf("Fomap ist da? %d Fo-Fcmap ist da? %d \n",chgl->fVertexes[2].isEmpty(),chgl->fVertexes[0].isEmpty());
 
   fxle->acnt=chgl->objCnt;
 }
 
 
 void FourXle::reportInfo(){
-    emit bigmessage(info);
+  emit bigmessage(info);
 }
 
 void FourXle::change_iso(int numsteps,int diff){
   /*! canges the iso value of the fo or fo-fc maps and redraws them
   */
-    printf("isochaged\n");
+  printf("isochaged\n");
   iso[diff]=fabs(iso[diff]);
   iso[diff]+=iso[diff]*numsteps/10.0f;
   int mi=0,ma=5;
@@ -1983,7 +2053,7 @@ void FourXle::makeFaces(int n, int faps, FNode poly[] ){
   }
   mid_nor2=Normalize(mid_nor2);
   for(int i=0; i<n; i++ ){
-      poly[i].normal = mid_nor2;
+    poly[i].normal = mid_nor2;
   }
   mid_ver *= (1.0/n);
   //mid_nor2= Normalize(mid_nor2);
@@ -1995,39 +2065,39 @@ void FourXle::makeFaces(int n, int faps, FNode poly[] ){
     else if (maptrunc==2) {
       mole->kart2frac(mid_ver+delDA[w],oc);
       int
-              ax = static_cast<int>((oc.x)/dxc.x-0.499),
-              bx = static_cast<int>((oc.y)/dyc.y-0.499),
-              cx = static_cast<int>((oc.z)/dzc.z-0.499);
+        ax = static_cast<int>((oc.x)/dxc.x-0.499),
+           bx = static_cast<int>((oc.y)/dyc.y-0.499),
+           cx = static_cast<int>((oc.z)/dzc.z-0.499);
       int DEX=dex3(ax,bx,cx);
       if (!noGoMap[DEX]) continue;
     }    
-      for (int k=1; k<n-1;k++){
-        tri++;
+    for (int k=1; k<n-1;k++){
+      tri++;
 
-        chgl->fVertexes[faps].append(poly[k].vertex.x+delDA[w].x);
-        chgl->fVertexes[faps].append(poly[k].vertex.y+delDA[w].y);
-        chgl->fVertexes[faps].append(poly[k].vertex.z+delDA[w].z);
+      chgl->fVertexes[faps].append(poly[k].vertex.x+delDA[w].x);
+      chgl->fVertexes[faps].append(poly[k].vertex.y+delDA[w].y);
+      chgl->fVertexes[faps].append(poly[k].vertex.z+delDA[w].z);
 
-        chgl->fVertexes[faps].append(poly[(k+1)].vertex.x+delDA[w].x);
-        chgl->fVertexes[faps].append(poly[(k+1)].vertex.y+delDA[w].y);
-        chgl->fVertexes[faps].append(poly[(k+1)].vertex.z+delDA[w].z);
+      chgl->fVertexes[faps].append(poly[(k+1)].vertex.x+delDA[w].x);
+      chgl->fVertexes[faps].append(poly[(k+1)].vertex.y+delDA[w].y);
+      chgl->fVertexes[faps].append(poly[(k+1)].vertex.z+delDA[w].z);
 
-        chgl->fVertexes[faps].append(poly[0].vertex.x+delDA[w].x);
-        chgl->fVertexes[faps].append(poly[0].vertex.y+delDA[w].y);
-        chgl->fVertexes[faps].append(poly[0].vertex.z+delDA[w].z);
+      chgl->fVertexes[faps].append(poly[0].vertex.x+delDA[w].x);
+      chgl->fVertexes[faps].append(poly[0].vertex.y+delDA[w].y);
+      chgl->fVertexes[faps].append(poly[0].vertex.z+delDA[w].z);
 
 
-        chgl->fNormals[faps].append(poly[k].normal.x);
-        chgl->fNormals[faps].append(poly[k].normal.y);
-        chgl->fNormals[faps].append(poly[k].normal.z);
+      chgl->fNormals[faps].append(poly[k].normal.x);
+      chgl->fNormals[faps].append(poly[k].normal.y);
+      chgl->fNormals[faps].append(poly[k].normal.z);
 
-        chgl->fNormals[faps].append(poly[(k+1)].normal.x);
-        chgl->fNormals[faps].append(poly[(k+1)].normal.y);
-        chgl->fNormals[faps].append(poly[(k+1)].normal.z);
+      chgl->fNormals[faps].append(poly[(k+1)].normal.x);
+      chgl->fNormals[faps].append(poly[(k+1)].normal.y);
+      chgl->fNormals[faps].append(poly[(k+1)].normal.z);
 
-        chgl->fNormals[faps].append(poly[0].normal.x);
-        chgl->fNormals[faps].append(poly[0].normal.y);
-        chgl->fNormals[faps].append(poly[0].normal.z);
+      chgl->fNormals[faps].append(poly[0].normal.x);
+      chgl->fNormals[faps].append(poly[0].normal.y);
+      chgl->fNormals[faps].append(poly[0].normal.z);
     }
     if (maptrunc==0) w=27;
   }
@@ -2099,7 +2169,7 @@ void FourXle::MakeElement(int ix, int iy, int iz , int s1, int s2, int faps) {
     }while( (i!=is)&&(n<11) );
     if (n>=3) {
       if (dis<5){
-          //for (int polni=0; polni<n; polni++){polygon[polni].normal+=Normalize((polygon[(polni+1)%n].vertex-polygon[polni].vertex)%(polygon[(polni+n-1)%n].vertex-polygon[polni].vertex));}
+        //for (int polni=0; polni<n; polni++){polygon[polni].normal+=Normalize((polygon[(polni+1)%n].vertex-polygon[polni].vertex)%(polygon[(polni+n-1)%n].vertex-polygon[polni].vertex));}
         makeFaces( n, faps, polygon );
       }//*
       else {
