@@ -1,21 +1,21 @@
 
 /****************************************************************************
-**
-** Copyright (C) 2011 Christian B. Huebschle & George M. Sheldrick
-** All rights reserved.
-** Contact: chuebsch@moliso.de
-**
-** This file is part of the ShelXle
-**
-** This file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 as published by the Free Software
-** Foundation and appearing in the file COPYING included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU Lesser General Public License version 2.1 requirements
-** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
-**
-**
-****************************************************************************/
+ **
+ ** Copyright (C) 2011 Christian B. Huebschle & George M. Sheldrick
+ ** All rights reserved.
+ ** Contact: chuebsch@moliso.de
+ **
+ ** This file is part of the ShelXle
+ **
+ ** This file may be used under the terms of the GNU Lesser
+ ** General Public License version 2.1 as published by the Free Software
+ ** Foundation and appearing in the file COPYING included in the
+ ** packaging of this file.  Please review the following information to
+ ** ensure the GNU Lesser General Public License version 2.1 requirements
+ ** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+ **
+ **
+ ****************************************************************************/
 #ifndef FOURXLE_H
 #define FOURXLE_H 1
 #include <stdio.h>
@@ -32,13 +32,13 @@
 
 //! Rec is a reflection type of a fcf 6 file.
 typedef struct {
-int  ih,//!< h
-     ik,//!< k
-     il;//!< l 
-float fo,//!< F observed
-      so,//!< \f$\sigma(observed)\f$
-      fc,//!< F calculated
-      phi; //!< \f$\varphi\f$ 
+  int  ih,//!< h
+       ik,//!< k
+       il;//!< l 
+  float fo,//!< F observed
+        so,//!< \f$\sigma(observed)\f$
+        fc,//!< F calculated
+        phi; //!< \f$\varphi\f$ 
 } Rec;
 #define LM 2000000
 //! FNode is a struct for the 3 different edges of a cube 
@@ -56,8 +56,8 @@ struct FNode {
   }
   friend inline double Distance( const FNode& n1, const FNode& n2 ){
     /*! @param n1,n2 nodes vor which the squared distance should be calculated.
-     \returns te positional squared distance between two nodes
-     */
+      \returns te positional squared distance between two nodes
+      */
     return Norm(n1.vertex-n2.vertex);
   }
 };
@@ -72,6 +72,7 @@ class FourXle:public QObject{
           *datfo_fc;//!<data pointer for the fobs-fcalc map in real space
     float f000;
     float overridef000;
+    bool isBelo;
     FourXle(Molecule *mole_, ChGL *chgl_,QToolBar *toolView, QProgressBar *bar,double resol=2.5, double wght=1.1);
     /*!< @param mole_ pointer to the Molecule of ShelXle 
      *  @param chgl_ pointer to the ChGL widged of ShelXle
@@ -94,7 +95,7 @@ class FourXle:public QObject{
     QVBoxLayout *amdl;
     QAction *keepiso;
     QAction *mapcontrol;
-    QCheckBox *ownfcf6;
+    QCheckBox *ownfcf6, *ownfcf6_;
     QString  fouName;
     void drawMap(int faps);
     int maptrunc;
@@ -131,8 +132,8 @@ class FourXle:public QObject{
     V3 dx,//!< vector in a direction for each map voxel
        dy,//!< vector in b direction for each map voxel
        dz;//!< vector in c direction for each map voxel
-public slots:
-    void bewegt(V3 v);
+    public slots:
+      void bewegt(V3 v);
     void inimap();
     void change_iso(int numsteps,int diff);
     void chglDestroyed();
@@ -184,11 +185,11 @@ signals:
     //          double minnor,maxnor;
     void gen_surface(bool neu,int imin=0, int imax=4);
     void CalcVertex( int ix, int iy, int iz);
-//    V3 CalcNormalX( int ix, int iy, int iz );
-//    V3 CalcNormalY( int ix, int iy, int iz );
-//    V3 CalcNormalZ( int ix, int iy, int iz );
+    //    V3 CalcNormalX( int ix, int iy, int iz );
+    //    V3 CalcNormalY( int ix, int iy, int iz );
+    //    V3 CalcNormalZ( int ix, int iy, int iz );
     int IndexSelected( FNode& node0, FNode& node1, FNode& node2, FNode& node3);
-//    V3& VectorSelected( FNode& node0, FNode& node1, FNode& node2, FNode& node3);
+    //    V3& VectorSelected( FNode& node0, FNode& node1, FNode& node2, FNode& node3);
     void MakeElement( int ix, int iy, int iz ,int s1, int s2, int faps);
     void makeFaces(int n, int faps, FNode poly[] );
 
@@ -204,32 +205,32 @@ signals:
 
 
 class GenMapWorker : public QThread{
-Q_OBJECT
+  Q_OBJECT
   public:
-  GenMapWorker(ChGL *chgl_,Molecule *mol_, FourXle *parent, bool neu_=true,int imin_=0, int imax_=4){
-    chgl = chgl_;
-    mole=mol_;
-    fxle = parent;// maybe I need it later?
-    neu=neu_;
-    imin=imin_;
-    imax=imax_;
-  }
-  ~GenMapWorker(){
-   //printf("destruct GenMapWorker\n");
-  }
+    GenMapWorker(ChGL *chgl_,Molecule *mol_, FourXle *parent, bool neu_=true,int imin_=0, int imax_=4){
+      chgl = chgl_;
+      mole=mol_;
+      fxle = parent;// maybe I need it later?
+      neu=neu_;
+      imin=imin_;
+      imax=imax_;
+    }
+    ~GenMapWorker(){
+      //printf("destruct GenMapWorker\n");
+    }
 
-  void run() {
-    /* expensive or blocking operation  */
-    gen_surface(neu, imin,imax);
-  }
-  void gen_surface(bool neu,int imin=0, int imax=4);
-  ChGL *chgl;
-  FourXle *fxle;//parent
-  Molecule *mole;
-  bool neu;
-  int imin,imax;
+    void run() {
+      /* expensive or blocking operation  */
+      gen_surface(neu, imin,imax);
+    }
+    void gen_surface(bool neu,int imin=0, int imax=4);
+    ChGL *chgl;
+    FourXle *fxle;//parent
+    Molecule *mole;
+    bool neu;
+    int imin,imax;
 signals:
-  void progress(int v);
+    void progress(int v);
 };
 
 
